Class: Ruport::Formatter::HTML

Inherits:
Ruport::Formatter show all
Defined in:
lib/ruport/formatter/html.rb

Overview

This class produces HTML output for Ruport's Row, Table, Group, and Grouping controllers. It can be subclassed, as it has some helper methods that might be useful for custom output.

Rendering Options

:show_table_headers True by default

:show_group_headers True by default

:style Used for grouping (:inline, :justified)

Instance Attribute Summary

Attributes inherited from Ruport::Formatter

#data, #format, #options

Instance Method Summary collapse